@@ -1,4 +1,4 @@
-# $Id: http.pm,v 1.65 2003/10/14 17:43:47 gisle Exp $
+# $Id: http.pm,v 1.67 2004/03/10 20:10:18 gisle Exp $
 #
 
 package LWP::Protocol::http;
@@ -147,7 +147,7 @@ sub request
 	$host = $url->host;
 	$port = $url->port;
 	$fullpath = $url->path_query;
-	$fullpath = "/" unless length $fullpath;
+	$fullpath = "/$fullpath" unless $fullpath =~ m,^/,;
     }
 
     # connect to remote site
@@ -177,7 +177,8 @@ sub request
 	    $has_content++;
 	    $chunked++;
 	}
-    } else {
+    }
+    else {
 	# Set (or override) Content-Length header
 	my $clen = $request_headers->header('Content-Length');
 	if (defined($$content_ref) && length($$content_ref)) {
